summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:00:08 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:00:08 -0600
commit7ff7bcc7ea84846c0e4dd51a4589300aea74acf5 (patch)
tree18df88bd6d1cf9404e082111fe54f1e4d4ddfdaa
parentfb26e15f2ed02caaa029409b2240690aaa693107 (diff)
downloadkvirc-7ff7bcc7.tar.gz
kvirc-7ff7bcc7.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
-rw-r--r--ChangeLog2
-rw-r--r--acinclude.m42
-rw-r--r--admin/acinclude.m4.in2
-rw-r--r--src/kvilib/ext/kvi_dcophelper.cpp2
-rw-r--r--src/kvilib/tal/kvi_tal_application.cpp4
-rw-r--r--src/kvilib/tal/kvi_tal_application_kde.h2
-rw-r--r--src/modules/mediaplayer/mp_dcopinterface.cpp2
7 files changed, 8 insertions, 8 deletions
diff --git a/ChangeLog b/ChangeLog
index a5f866fd..b558d943 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -932,7 +932,7 @@ Oct 2006
- Fixed several bugtrack issues.
- Cleaned up the -ansi -pedantic compilation. It looks that
only one real warning remains and it is related to the "deprecated"
- flags of KApplication constructor which will be removed
+ flags of TDEApplication constructor which will be removed
in KDE 4.0. We must live with it for a while.
All the other warnings are due to the system headers.
- Caught a couple of potential segmentation faults in the reguser
diff --git a/acinclude.m4 b/acinclude.m4
index 563500f3..15869676 100644
--- a/acinclude.m4
+++ b/acinclude.m4
@@ -2312,7 +2312,7 @@ AC_DEFUN([AC_SS_ENSURE_CAN_COMPILE_X_QT3_AND_KDE],
#include "twin.h"
],[
int a = KWin::currentDesktop();
- KApplication app(a,0,"kvirc");
+ TDEApplication app(a,0,"kvirc");
],
SS_KQTX_LINKED_OK="TRUE",
SS_KQTX_LINKED_OK="FALSE"
diff --git a/admin/acinclude.m4.in b/admin/acinclude.m4.in
index caa732cd..e9a5ebec 100644
--- a/admin/acinclude.m4.in
+++ b/admin/acinclude.m4.in
@@ -2339,7 +2339,7 @@ AC_DEFUN([AC_SS_ENSURE_CAN_COMPILE_X_QT3_AND_KDE],
#include "twin.h"
],[
int a = KWin::currentDesktop();
- KApplication app(a,0,"kvirc");
+ TDEApplication app(a,0,"kvirc");
],
SS_KQTX_LINKED_OK="TRUE",
SS_KQTX_LINKED_OK="FALSE"
diff --git a/src/kvilib/ext/kvi_dcophelper.cpp b/src/kvilib/ext/kvi_dcophelper.cpp
index a181d10d..8c7f7c04 100644
--- a/src/kvilib/ext/kvi_dcophelper.cpp
+++ b/src/kvilib/ext/kvi_dcophelper.cpp
@@ -311,7 +311,7 @@ int KviDCOPHelper::detectApp(const TQString &szApp,bool bStart,int iScoreWhenFou
bool KviDCOPHelper::startApp(const TQString &szApp,int iWaitMSecs)
{
- // we could use KApplication::startServiceByDesktopName here
+ // we could use TDEApplication::startServiceByDesktopName here
// but we want to be able to wait a defined amount of time
TQStringList tmp;
TQByteArray data, replyData;
diff --git a/src/kvilib/tal/kvi_tal_application_kde.h b/src/kvilib/tal/kvi_tal_application_kde.h
index ee6e653c..c9118509 100644
--- a/src/kvilib/tal/kvi_tal_application_kde.h
+++ b/src/kvilib/tal/kvi_tal_application_kde.h
@@ -26,7 +26,7 @@
#include <kapp.h>
-class KVILIB_API KviTalApplication : public KApplication
+class KVILIB_API KviTalApplication : public TDEApplication
{
Q_OBJECT
diff --git a/src/modules/mediaplayer/mp_dcopinterface.cpp b/src/modules/mediaplayer/mp_dcopinterface.cpp
index 639c0757..d32b99f3 100644
--- a/src/modules/mediaplayer/mp_dcopinterface.cpp
+++ b/src/modules/mediaplayer/mp_dcopinterface.cpp
@@ -178,7 +178,7 @@ int KviMediaPlayerDCOPInterface::detectApp(const TQString &szApp,bool bStart,int
bool KviMediaPlayerDCOPInterface::startApp(const TQString &szApp,int iWaitMSecs)
{
- // we could use KApplication::startServiceByDesktopName here
+ // we could use TDEApplication::startServiceByDesktopName here
// but we want to be able to wait a defined amount of time
TQStringList tmp;
TQByteArray data, replyData;
diff --git a/src/kvilib/tal/kvi_tal_application.cpp b/src/kvilib/tal/kvi_tal_application.cpp
index a637c676..b372dfaa 100644
--- a/src/kvilib/tal/kvi_tal_application.cpp
+++ b/src/kvilib/tal/kvi_tal_application.cpp
@@ -33,14 +33,14 @@
// ../tal/kvi_tal_application.cpp:31: warning: `__base_ctor' is deprecated
// (declared at /opt/kde/include/kapplication.h:198)
//
// The KApplication constructor has been declared as deprecated
// in favor of a complexier initialization that uses TDECmdLineArgs
// and can't be abstracted easily.
// The other constructors are not "old" and "stable" enough
// to be safely used at this time. We'll rethink this when KDE 4 is out.
KviTalApplication::KviTalApplication(int &argc,char ** argv)
- : KApplication(argc,argv,"kvirc")
+ : TDEApplication(argc,argv,"kvirc")
{
@@ -33,14 +33,14 @@
// (declared at /opt/kde/include/kapplication.h:198)
//
- // The KApplication constructor has been declared as deprecated
+ // The TDEApplication constructor has been declared as deprecated
// in favor of a complexier initialization that uses TDECmdLineArgs
// and can't be abstracted easily.